@@ -14,7 +14,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, Dict, IO, List, TYPE_CHECKING, Type, Union, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_codeguruprofiler.paginator import ListProfileTimesPaginator
 from mypy_boto3_codeguruprofiler.type_defs import (
@@ -52,43 +52,43 @@ class Exceptions:
 
 class CodeGuruProfilerClient:
     """
-    [CodeGuruProfiler.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
+    [CodeGuruProfiler.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
         """
 
     def configure_agent(
         self, profilingGroupName: str, fleetInstanceId: str = None
     ) -> ConfigureAgentResponseTypeDef:
         """
-        [Client.configure_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
+        [Client.configure_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
         """
 
     def create_profiling_group(
         self,
         clientToken: str,
         profilingGroupName: str,
-        agentOrchestrationConfig: AgentOrchestrationConfigTypeDef = None,
+        agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef" = None,
     ) -> CreateProfilingGroupResponseTypeDef:
         """
-        [Client.create_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
+        [Client.create_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
         """
 
     def delete_profiling_group(self, profilingGroupName: str) -> Dict[str, Any]:
         """
-        [Client.delete_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
+        [Client.delete_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
         """
 
     def describe_profiling_group(
         self, profilingGroupName: str
     ) -> DescribeProfilingGroupResponseTypeDef:
         """
-        [Client.describe_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
+        [Client.describe_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
         """
 
     def generate_presigned_url(
@@ -99,12 +99,12 @@ class CodeGuruProfilerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
         """
 
     def get_policy(self, profilingGroupName: str) -> GetPolicyResponseTypeDef:
         """
-        [Client.get_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
+        [Client.get_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
         """
 
     def get_profile(
@@ -117,7 +117,7 @@ class CodeGuruProfilerClient:
         startTime: datetime = None,
     ) -> GetProfileResponseTypeDef:
         """
-        [Client.get_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
+        [Client.get_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
         """
 
     def list_profile_times(
@@ -131,25 +131,25 @@ class CodeGuruProfilerClient:
         orderBy: Literal["TimestampAscending", "TimestampDescending"] = None,
     ) -> ListProfileTimesResponseTypeDef:
         """
-        [Client.list_profile_times documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
+        [Client.list_profile_times documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
         """
 
     def list_profiling_groups(
         self, includeDescription: bool = None, maxResults: int = None, nextToken: str = None
     ) -> ListProfilingGroupsResponseTypeDef:
         """
-        [Client.list_profiling_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
+        [Client.list_profiling_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
         """
 
     def post_agent_profile(
         self,
-        agentProfile: Union[bytes, IO],
+        agentProfile: bytes,
         contentType: str,
         profilingGroupName: str,
         profileToken: str = None,
     ) -> Dict[str, Any]:
         """
-        [Client.post_agent_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
+        [Client.post_agent_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
         """
 
     def put_permission(
@@ -160,21 +160,21 @@ class CodeGuruProfilerClient:
         revisionId: str = None,
     ) -> PutPermissionResponseTypeDef:
         """
-        [Client.put_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
+        [Client.put_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
         """
 
     def remove_permission(
         self, actionGroup: Literal["agentPermissions"], profilingGroupName: str, revisionId: str
     ) -> RemovePermissionResponseTypeDef:
         """
-        [Client.remove_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
+        [Client.remove_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
         """
 
     def update_profiling_group(
-        self, agentOrchestrationConfig: AgentOrchestrationConfigTypeDef, profilingGroupName: str
+        self, agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef", profilingGroupName: str
     ) -> UpdateProfilingGroupResponseTypeDef:
         """
-        [Client.update_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
+        [Client.update_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
         """
 
     @overload
@@ -182,5 +182,5 @@ class CodeGuruProfilerClient:
         self, operation_name: Literal["list_profile_times"]
     ) -> ListProfileTimesPaginator:
         """
-        [Paginator.ListProfileTimes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.22/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+        [Paginator.ListProfileTimes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
         """
