@@ -3,13 +3,13 @@ Main interface for codeguruprofiler service type definitions.
 
 Usage::
 
-    from mypy_boto3.codeguruprofiler.type_defs import AgentOrchestrationConfigTypeDef
+    from mypy_boto3.codeguruprofiler.type_defs import AgentConfigurationTypeDef
 
-    data: AgentOrchestrationConfigTypeDef = {...}
+    data: AgentConfigurationTypeDef = {...}
 """
 from datetime import datetime
 import sys
-from typing import IO, List, Union
+from typing import List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -22,17 +22,17 @@ else:
 
 
 __all__ = (
-    "AgentOrchestrationConfigTypeDef",
     "AgentConfigurationTypeDef",
-    "ConfigureAgentResponseTypeDef",
+    "AgentOrchestrationConfigTypeDef",
     "AggregatedProfileTimeTypeDef",
-    "ProfilingStatusTypeDef",
+    "ProfileTimeTypeDef",
     "ProfilingGroupDescriptionTypeDef",
+    "ProfilingStatusTypeDef",
+    "ConfigureAgentResponseTypeDef",
     "CreateProfilingGroupResponseTypeDef",
     "DescribeProfilingGroupResponseTypeDef",
     "GetPolicyResponseTypeDef",
     "GetProfileResponseTypeDef",
-    "ProfileTimeTypeDef",
     "ListProfileTimesResponseTypeDef",
     "ListProfilingGroupsResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -41,16 +41,12 @@ __all__ = (
     "UpdateProfilingGroupResponseTypeDef",
 )
 
-AgentOrchestrationConfigTypeDef = TypedDict(
-    "AgentOrchestrationConfigTypeDef", {"profilingEnabled": bool}
-)
-
 AgentConfigurationTypeDef = TypedDict(
     "AgentConfigurationTypeDef", {"periodInSeconds": int, "shouldProfile": bool}
 )
 
-ConfigureAgentResponseTypeDef = TypedDict(
-    "ConfigureAgentResponseTypeDef", {"configuration": AgentConfigurationTypeDef}
+AgentOrchestrationConfigTypeDef = TypedDict(
+    "AgentOrchestrationConfigTypeDef", {"profilingEnabled": bool}
 )
 
 AggregatedProfileTimeTypeDef = TypedDict(
@@ -59,41 +55,47 @@ AggregatedProfileTimeTypeDef = TypedDict(
     total=False,
 )
 
-ProfilingStatusTypeDef = TypedDict(
-    "ProfilingStatusTypeDef",
-    {
-        "latestAgentOrchestratedAt": datetime,
-        "latestAgentProfileReportedAt": datetime,
-        "latestAggregatedProfile": AggregatedProfileTimeTypeDef,
-    },
-    total=False,
-)
+ProfileTimeTypeDef = TypedDict("ProfileTimeTypeDef", {"start": datetime}, total=False)
 
 ProfilingGroupDescriptionTypeDef = TypedDict(
     "ProfilingGroupDescriptionTypeDef",
     {
-        "agentOrchestrationConfig": AgentOrchestrationConfigTypeDef,
+        "agentOrchestrationConfig": "AgentOrchestrationConfigTypeDef",
         "arn": str,
         "createdAt": datetime,
         "name": str,
-        "profilingStatus": ProfilingStatusTypeDef,
+        "profilingStatus": "ProfilingStatusTypeDef",
         "updatedAt": datetime,
     },
     total=False,
 )
 
+ProfilingStatusTypeDef = TypedDict(
+    "ProfilingStatusTypeDef",
+    {
+        "latestAgentOrchestratedAt": datetime,
+        "latestAgentProfileReportedAt": datetime,
+        "latestAggregatedProfile": "AggregatedProfileTimeTypeDef",
+    },
+    total=False,
+)
+
+ConfigureAgentResponseTypeDef = TypedDict(
+    "ConfigureAgentResponseTypeDef", {"configuration": "AgentConfigurationTypeDef"}
+)
+
 CreateProfilingGroupResponseTypeDef = TypedDict(
-    "CreateProfilingGroupResponseTypeDef", {"profilingGroup": ProfilingGroupDescriptionTypeDef}
+    "CreateProfilingGroupResponseTypeDef", {"profilingGroup": "ProfilingGroupDescriptionTypeDef"}
 )
 
 DescribeProfilingGroupResponseTypeDef = TypedDict(
-    "DescribeProfilingGroupResponseTypeDef", {"profilingGroup": ProfilingGroupDescriptionTypeDef}
+    "DescribeProfilingGroupResponseTypeDef", {"profilingGroup": "ProfilingGroupDescriptionTypeDef"}
 )
 
 GetPolicyResponseTypeDef = TypedDict("GetPolicyResponseTypeDef", {"policy": str, "revisionId": str})
 
 _RequiredGetProfileResponseTypeDef = TypedDict(
-    "_RequiredGetProfileResponseTypeDef", {"contentType": str, "profile": Union[bytes, IO]}
+    "_RequiredGetProfileResponseTypeDef", {"contentType": str, "profile": bytes}
 )
 _OptionalGetProfileResponseTypeDef = TypedDict(
     "_OptionalGetProfileResponseTypeDef", {"contentEncoding": str}, total=False
@@ -106,10 +108,8 @@ class GetProfileResponseTypeDef(
     pass
 
 
-ProfileTimeTypeDef = TypedDict("ProfileTimeTypeDef", {"start": datetime}, total=False)
-
 _RequiredListProfileTimesResponseTypeDef = TypedDict(
-    "_RequiredListProfileTimesResponseTypeDef", {"profileTimes": List[ProfileTimeTypeDef]}
+    "_RequiredListProfileTimesResponseTypeDef", {"profileTimes": List["ProfileTimeTypeDef"]}
 )
 _OptionalListProfileTimesResponseTypeDef = TypedDict(
     "_OptionalListProfileTimesResponseTypeDef", {"nextToken": str}, total=False
@@ -127,7 +127,7 @@ _RequiredListProfilingGroupsResponseTypeDef = TypedDict(
 )
 _OptionalListProfilingGroupsResponseTypeDef = TypedDict(
     "_OptionalListProfilingGroupsResponseTypeDef",
-    {"nextToken": str, "profilingGroups": List[ProfilingGroupDescriptionTypeDef]},
+    {"nextToken": str, "profilingGroups": List["ProfilingGroupDescriptionTypeDef"]},
     total=False,
 )
 
@@ -151,5 +151,5 @@ RemovePermissionResponseTypeDef = TypedDict(
 )
 
 UpdateProfilingGroupResponseTypeDef = TypedDict(
-    "UpdateProfilingGroupResponseTypeDef", {"profilingGroup": ProfilingGroupDescriptionTypeDef}
+    "UpdateProfilingGroupResponseTypeDef", {"profilingGroup": "ProfilingGroupDescriptionTypeDef"}
 )
